package cz.zweistein.df.soundsense.config;

import java.io.FileInputStream;
import java.io.IOException;
import java.util.logging.Logger;

import org.w3c.dom.Document;
import org.w3c.dom.Element;
import org.w3c.dom.Node;
import org.xml.sax.InputSource;
import org.xml.sax.SAXException;

import com.sun.org.apache.xerces.internal.parsers.DOMParser;

import cz.zweistein.df.soundsense.util.LoggerSource;

public class ConfigurationXML {
	private static Logger logger = LoggerSource.logger;
	
	private String fileName;
	
	private String gamelogPath;
	private String soundpacksPath;
	private float volume;

	public ConfigurationXML(String configurationFile) throws SAXException, IOException {
		
		this.fileName = configurationFile;
		
		Document doc = null;
		InputSource source = new InputSource(new FileInputStream(this.fileName));
		DOMParser parser = new DOMParser();
		parser.parse(source);
		doc = parser.getDocument();
		
		Element configNodes = (Element) doc.getElementsByTagName("configuration").item(0);
		
		Node gamelogNode = configNodes.getElementsByTagName("gamelog").item(0);
		this.gamelogPath = gamelogNode.getAttributes().getNamedItem("path").getNodeValue();
		
		Node soundpacksNode = configNodes.getElementsByTagName("soundpacks").item(0);
		this.soundpacksPath = soundpacksNode.getAttributes().getNamedItem("path").getNodeValue();
		
		Node volumeNode = configNodes.getElementsByTagName("volume").item(0);
		String volumeAdjustmentText = volumeNode.getAttributes().getNamedItem("value").getNodeValue();
		try {
			this.volume = Float.parseFloat(volumeAdjustmentText);
		} catch (NumberFormatException e) {
			logger.info("Volume value '"+volumeAdjustmentText+" is not recognized as a number, using default "+this.volume+".");
		}
		
	}
	
	public String getGamelogPath() {
		return this.gamelogPath;
	}
	
	public String getSoundpacksPath() {
		return this.soundpacksPath;
	}

	public float getVolume() {
		return this.volume;
	}
	
}
